@@ -1,4 +1,4 @@
-use crate::types::{StatusCode, ErrorResult};
+use crate::types::{StatusCode, ErrorResult, SendMessageParseMode};
 use crate::isahc_utils::*;
 use isahc::error::ErrorKind;
 
@@ -21,3 +21,18 @@ pub fn create_error_result_kind(code: StatusCode, kind: ErrorKind) -> Result<(),
 pub fn create_error_result_str(code: StatusCode, msg: &str) -> Result<(), ErrorResult> {
     Err(ErrorResult { code: code as u16, msg: msg.to_string() })
 }
+
+/// Get a string representing of specified parse mode.
+///
+/// This function returns static string as it is expected to be used across
+/// the lifetime of the application. So it has no need to return new instance
+/// of `String` every time.
+///
+/// # Arguments
+/// * `mode` - parse mode
+pub fn get_send_message_parse_mode_str(mode: SendMessageParseMode) -> &'static str {
+    match mode {
+        SendMessageParseMode::MarkdownV2 => "MarkdownV2",
+        SendMessageParseMode::HTML => "HTML",
+    }
+}
